@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: HTTP
 version: 4000.3.3
-id: HTTP-4000.3.3-7109897251a899dcae4c73aced404403
-key: HTTP_FcTxZYuZP86Ihm2U4PRa0R
+id: HTTP-4000.3.3-e80abaf8bcce3e49baa17e1fe8d694c7
+key: HTTP_DN8N8d1yGGGJEl6MCfC5ZZ
 license: BSD3
 maintainer: Ganesh Sittampalam <ganesh@earth.li>
 homepage: https://github.com/haskell/HTTP
@@ -53,15 +53,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/HTTP-4000.3.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/HTTP-4000.3.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/HTTP-4000.3.3
-hs-libraries: HSHTTP-4000.3.3-FcTxZYuZP86Ihm2U4PRa0R
+hs-libraries: HSHTTP-4000.3.3-DN8N8d1yGGGJEl6MCfC5ZZ
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
+    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
+    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
 haddock-interfaces: /usr/share/doc/haskell-http/html/HTTP.haddock
 haddock-html: /usr/share/doc/haskell-http/html
